# from os.path import isfile
# from os.path import dirname
from markdown_predictions.trainer import get_data, get_path

# version_file = '{}/version.txt'.format(dirname(__file__))

# if isfile(version_file):
#     with open(version_file) as version_file:
#         __version__ = version_file.read().strip()
